.. whereto documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

========================================
 whereto: Testing Apache Redirect Rules
========================================

whereto is an app for testing redirect rules like what may appear in a
.htaccess file for Apache. It provides a way to test those rules in CI
jobs.

:Source: http://git.openstack.org/cgit/openstack/whereto
:Bugs: http://bugs.launchpad.net/whereto

.. toctree::
   :maxdepth: 2

   install/index
   contributor/index
   cli/index
   user/index
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
